
# Slot: occurs in


holds between a process and a material entity or site within which the process occurs

URI: [biolink:occurs_in](https://w3id.org/biolink/vocab/occurs_in)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | BFO:0000066 |
|  | | PathWhiz:has_location |
|  | | SNOMED:occurs_in |
| **Close Mappings:** | | BFO:0000067 |
|  | | SNOMED:has_occurrence |
|  | | UBERON:site_of |
| **Narrow Mappings:** | | SEMMEDDB:OCCURS_IN |
|  | | SEMMEDDB:occurs_in |
|  | | SEMMEDDB:PROCESS_OF |
|  | | SEMMEDDB:process_of |
|  | | UBERON_CORE:site_of |
|  | | LOINC:has_imaged_location |
|  | | PathWhiz:in_species |
|  | | RO:0002231 |
|  | | RO:0002232 |
|  | | SNOMED:has_direct_procedure_site |
|  | | SNOMED:has_direct_site |
|  | | SNOMED:has_procedure_site |

